pub struct WebClosurePool { /* private fields */ }Expand description
Pool of reusable JavaScript closures for web platform optimization
Implementations
Sourceimpl WebClosurePool
impl WebClosurePool
Sourcepub fn execute_callback(&mut self, callback_id: u32)
pub fn execute_callback(&mut self, callback_id: u32)
Executes a registered callback and returns the closure to the pool
Arguments
callback_id- The ID of the callback to execute
Sourcepub fn create_js_closure(&self, callback_id: u32) -> Closure<dyn FnMut()>
pub fn create_js_closure(&self, callback_id: u32) -> Closure<dyn FnMut()>
Sourcepub fn available_count(&self) -> usize
pub fn available_count(&self) -> usize
Gets the number of available closures in the pool
Sourcepub fn in_use_count(&self) -> usize
pub fn in_use_count(&self) -> usize
Gets the number of closures currently in use