Module sequence

Module sequence 

AnimationSequence<T> - Optimized animation step sequences

Structs

AnimationSequence
Animation sequence that keeps step data simple and stores only the mutable execution state behind a mutex for shared access.
AnimationStep