AnimationSequence<T> - Optimized animation step sequences
Structs
- Animation
Sequence - Animation sequence that keeps step data simple and stores only the mutable execution state behind a mutex for shared access.
- Animation
Step
AnimationSequence<T> - Optimized animation step sequences